@@ -1,5 +1,5 @@
 /* 
- * $Id: RS-DBI.c,v 1.5 2002/05/20 20:55:45 dj Exp dj $ 
+ * $Id: RS-DBI.c,v 1.6 2002/08/24 02:13:39 dj Exp dj $ 
  *
  *
  * Copyright (C) 1999-2002 The Omega Project for Statistical Computing
@@ -229,17 +229,17 @@ RS_DBI_freeConnection(Con_Handle *conHandle)
   }
   if(con->drvConnection) {
     char *errMsg = 
-      "internal error: driver might have left open its connection on the server";
+      "internal error in RS_DBI_freeConnection: driver might have left open its connection on the server";
     RS_DBI_errorMessage(errMsg, RS_DBI_WARNING);
   }
   if(con->conParams){
     char *errMsg =
-      "internal error: non-freed con->conParams (tiny memory leaked)";
+      "internal error in RS_DBI_freeConnection: non-freed con->conParams (tiny memory leaked)";
     RS_DBI_errorMessage(errMsg, RS_DBI_WARNING);
   }
   if(con->drvData){
     char *errMsg = 
-      "internal error: non-freed con->drvData (some memory leaked)";
+      "internal error in RS_DBI_freeConnection: non-freed con->drvData (some memory leaked)";
     RS_DBI_errorMessage(errMsg, RS_DBI_WARNING);
   }
   /* delete this connection from manager's connection table */
@@ -317,12 +317,12 @@ RS_DBI_freeResultSet(Res_Handle *rsHandle)
 
   if(result->drvResultSet) {
     char *errMsg = 
-      "internal error: non-freed result->drvResultSet (some memory leaked)";
+      "internal error in RS_DBI_freeResultSet: non-freed result->drvResultSet (some memory leaked)";
     RS_DBI_errorMessage(errMsg, RS_DBI_ERROR);
   }
   if(result->drvData){
     char *errMsg =
-      "internal error: non-freed result->drvData (some memory leaked)";
+      "internal error in RS_DBI_freeResultSet: non-freed result->drvData (some memory leaked)";
     RS_DBI_errorMessage(errMsg, RS_DBI_WARNING);
   }
   if(result->statement)
@@ -404,7 +404,7 @@ RS_DBI_makeDataFrame(s_object *data)
       data = AS_LIST(data);
    else
       RS_DBI_errorMessage(
-            "internal error: could not corce named-list into data.frame",
+            "internal error in RS_DBI_makeDataFrame: could not corce named-list into data.frame",
             RS_DBI_ERROR);
 #endif
 
@@ -452,7 +452,8 @@ RS_DBI_allocOutput(s_object *output, RS_DBI_fields *flds,
   if(IS_LIST(output))
     output = AS_LIST(output);
   else 
-    RS_DBI_errorMessage("internal error: could not (re)allocate output list",
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_allocOutput: could not (re)allocate output list",
                         RS_DBI_ERROR);
 #endif
 
@@ -562,8 +563,9 @@ RS_DBI_setException(Db_Handle *handle, DBI_EXCEPTION exceptionType,
     obj->exception->errorMsg = RS_DBI_copyString(errorMsg);
   } 
   else {
-    RS_DBI_errorMessage("internal error: could not setException",
-		    RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_setException: could not setException",
+          RS_DBI_ERROR);
   }
   return;
 }
@@ -598,8 +600,9 @@ RS_DBI_copyString(const char *str)
 
   buffer = (char *) malloc((size_t) strlen(str)+1);
   if(!buffer)
-    RS_DBI_errorMessage("internal error: could not alloc string space", 
-			RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_copyString: could not alloc string space", 
+          RS_DBI_ERROR);
   return strcpy(buffer, str);
 }
 
@@ -660,8 +663,9 @@ RS_DBI_copyfields(RS_DBI_fields *flds)
   if(IS_LIST(S_fields))
     S_fields = AS_LIST(S_fields);
   else
-    RS_DBI_errorMessage("internal error: could not alloc named list",
-                         RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_copyfields: could not alloc named list",
+          RS_DBI_ERROR);
 #endif
   /* copy contentes from flds into an R/S list */
   for(i = 0; i < num_fields; i++){
@@ -731,11 +735,19 @@ RS_DBI_SclassNames(s_object *type)
   int  i;
   char *s;
   
+  if(type==S_NULL_ENTRY)
+     RS_DBI_errorMessage(
+           "internal error in RS_DBI_SclassNames: input S types must be nonNULL",
+           RS_DBI_ERROR);
   n = LENGTH(type);
   typeCodes = INTEGER_DATA(type);
   MEM_PROTECT(typeNames = NEW_CHARACTER(n));
   for(i = 0; i < n; i++) {
     s = RS_DBI_getTypeName(typeCodes[i], RS_dataTypeTable);
+    if(!s)
+      RS_DBI_errorMessage(
+            "internal error RS_DBI_SclassNames: unrecognized S type", 
+            RS_DBI_ERROR);
     SET_CHR_EL(typeNames, i, C_S_CPY(s));
   }
   MEM_UNPROTECT(1);
@@ -791,8 +803,9 @@ RS_DBI_getManager(Mgr_Handle *handle)
     RS_DBI_errorMessage("invalid dbManager handle", RS_DBI_ERROR);
   mgr = dbManager;
   if(!mgr)
-    RS_DBI_errorMessage("internal error: corrupt dbManager object",
-			RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_getManager: corrupt dbManager handle",
+	  RS_DBI_ERROR);
   return mgr;
 }
 
@@ -805,11 +818,13 @@ RS_DBI_getConnection(Con_Handle *conHandle)
   mgr = RS_DBI_getManager(conHandle);
   indx = RS_DBI_lookup(mgr->connectionIds, mgr->length, CON_ID(conHandle));
   if(indx < 0)
-    RS_DBI_errorMessage("internal error: corrupt dbManager object",
-		       RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_getConnection: corrupt connection handle",
+	  RS_DBI_ERROR);
   if(!mgr->connections[indx])
-    RS_DBI_errorMessage("internal error: corrupt dbManager object",
-		       RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_getConnection: corrupt connection  object",
+	  RS_DBI_ERROR);
   return mgr->connections[indx];
 }
 
@@ -823,11 +838,12 @@ RS_DBI_getResultSet(Res_Handle *rsHandle)
   indx = RS_DBI_lookup(con->resultSetIds, con->length, RES_ID(rsHandle));
   if(indx<0)
     RS_DBI_errorMessage(
-      "internal error: could not find resultSet in connection",
+      "internal error in RS_DBI_getResultSet: could not find resultSet in connection",
       RS_DBI_ERROR);
   if(!con->resultSets[indx])
-    RS_DBI_errorMessage("internal error: missing resultSet",
-                        RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_getResultSet: missing resultSet",
+          RS_DBI_ERROR);
   return con->resultSets[indx];
 }
 
@@ -963,8 +979,9 @@ RS_DBI_managerInfo(Mgr_Handle *mgrHandle)
   if(IS_LIST(output))
     output = AS_LIST(output);
   else
-    RS_DBI_errorMessage("internal error: could not alloc named list", 
-			RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error: could not alloc named list", 
+    	  RS_DBI_ERROR);
 #endif
   for(i = 0; i < num_con; i++)
     LST_INT_EL(output,0,i) = (Sint) mgr->connectionIds[i];
@@ -1008,8 +1025,9 @@ RS_DBI_connectionInfo(Con_Handle *conHandle)
   if(IS_LIST(output))
     output = AS_LIST(output);
   else
-    RS_DBI_errorMessage("internal error: could not alloc named list",
-			RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_connectionInfo: could not alloc named list",
+	  RS_DBI_ERROR);
 #endif
   /* dummy */
   SET_LST_CHR_EL(output,0,0,C_S_CPY("NA"));        /* host */
@@ -1052,8 +1070,9 @@ RS_DBI_resultSetInfo(Res_Handle *rsHandle)
   if(IS_LIST(output))
     output = AS_LIST(output);
   else
-    RS_DBI_errorMessage("internal error: could not alloc named list",
-			RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_resultSetInfo: could not alloc named list",
+	  RS_DBI_ERROR);
 #endif
   SET_LST_CHR_EL(output,0,0,C_S_CPY(result->statement));
   LST_INT_EL(output,1,0) = result->isSelect;
@@ -1089,8 +1108,9 @@ RS_DBI_getFieldDescriptions(RS_DBI_fields *flds)
   if(IS_LIST(S_fields))
     S_fields = AS_LIST(S_fields);
   else
-    RS_DBI_errorMessage("internal error: could not alloc named list",
-			RS_DBI_ERROR);
+    RS_DBI_errorMessage(
+          "internal error in RS_DBI_getFieldDescription: could not alloc named list",
+          RS_DBI_ERROR);
 #endif
   /* copy contentes from flds into an R/S list */
   for(i = 0; i < (Sint) num_fields; i++){
